@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from flask import Flask, render_template
 from packagesample import __version__, log
+from packagesample.modules import *
 
 app = Flask(__name__)
 
@@ -12,7 +13,7 @@ def get_title():
 
 @app.route("/")
 def home():
-    return render_template('start.html')
+    return render_template('start.html', text = module.main())
 
 
 def main():
